@@ -2,7 +2,7 @@ use postgres_protocol::types;
 use std::{i32, i64};
 use std::error::Error;
 
-use types::{Type, FromSql, ToSql, IsNull};
+use types::{Type, FromSql, ToSql, IsNull, DATE, TIMESTAMP, TIMESTAMPTZ};
 
 /// A wrapper that can be used to represent infinity with `Type::Date` types.
 #[derive(Debug, Clone, Copy, PartialEq)]
@@ -16,9 +16,7 @@ pub enum Date<T> {
 }
 
 impl<T: FromSql> FromSql for Date<T> {
-    fn from_sql(ty: &Type,
-                raw: &[u8])
-                -> Result<Self, Box<Error + Sync + Send>> {
+    fn from_sql(ty: &Type, raw: &[u8]) -> Result<Self, Box<Error + Sync + Send>> {
         match types::date_from_sql(raw)? {
             i32::MAX => Ok(Date::PosInfinity),
             i32::MIN => Ok(Date::NegInfinity),
@@ -27,14 +25,11 @@ impl<T: FromSql> FromSql for Date<T> {
     }
 
     fn accepts(ty: &Type) -> bool {
-        *ty == Type::Date && T::accepts(ty)
+        *ty == DATE && T::accepts(ty)
     }
 }
 impl<T: ToSql> ToSql for Date<T> {
-    fn to_sql(&self,
-              ty: &Type,
-              out: &mut Vec<u8>)
-              -> Result<IsNull, Box<Error + Sync + Send>> {
+    fn to_sql(&self, ty: &Type, out: &mut Vec<u8>) -> Result<IsNull, Box<Error + Sync + Send>> {
         let value = match *self {
             Date::PosInfinity => i32::MAX,
             Date::NegInfinity => i32::MIN,
@@ -46,7 +41,7 @@ impl<T: ToSql> ToSql for Date<T> {
     }
 
     fn accepts(ty: &Type) -> bool {
-        *ty == Type::Date && T::accepts(ty)
+        *ty == DATE && T::accepts(ty)
     }
 
     to_sql_checked!();
@@ -65,9 +60,7 @@ pub enum Timestamp<T> {
 }
 
 impl<T: FromSql> FromSql for Timestamp<T> {
-    fn from_sql(ty: &Type,
-                raw: &[u8])
-                -> Result<Self, Box<Error + Sync + Send>> {
+    fn from_sql(ty: &Type, raw: &[u8]) -> Result<Self, Box<Error + Sync + Send>> {
         match types::timestamp_from_sql(raw)? {
             i64::MAX => Ok(Timestamp::PosInfinity),
             i64::MIN => Ok(Timestamp::NegInfinity),
@@ -76,15 +69,15 @@ impl<T: FromSql> FromSql for Timestamp<T> {
     }
 
     fn accepts(ty: &Type) -> bool {
-        (*ty == Type::Timestamp || *ty == Type::Timestamptz) && T::accepts(ty)
+        match *ty {
+            TIMESTAMP | TIMESTAMPTZ if T::accepts(ty) => true,
+            _ => false
+        }
     }
 }
 
 impl<T: ToSql> ToSql for Timestamp<T> {
-    fn to_sql(&self,
-              ty: &Type,
-              out: &mut Vec<u8>)
-              -> Result<IsNull, Box<Error + Sync + Send>> {
+    fn to_sql(&self, ty: &Type, out: &mut Vec<u8>) -> Result<IsNull, Box<Error + Sync + Send>> {
         let value = match *self {
             Timestamp::PosInfinity => i64::MAX,
             Timestamp::NegInfinity => i64::MIN,
@@ -96,7 +89,10 @@ impl<T: ToSql> ToSql for Timestamp<T> {
     }
 
     fn accepts(ty: &Type) -> bool {
-        (*ty == Type::Timestamp || *ty == Type::Timestamptz) && T::accepts(ty)
+        match *ty {
+            TIMESTAMP | TIMESTAMPTZ if T::accepts(ty) => true,
+            _ => false
+        }
     }
 
     to_sql_checked!();
